const validateSchema = (data, schema) => {
    return new Promise((resolve, reject) => {
        if (typeof data === "object" && !Array.isArray(data)) {
            if (typeof schema === "object" && !Array.isArray(schema)) {
                let dataKeys = Object.keys(data)
                let schemaKeys = Object.keys(schema)
                if (dataKeys.length === schemaKeys.length) {
                    for (key in schemaKeys) {
                        let property = schemaKeys[key]
                        let schemaFunction = schema[property]
                        if (typeof schemaFunction === "function"){
                            if (data.hasOwnProperty(property)) {
                                try {
                                    schemaFunction(data[property])
                                } catch (e) {
                                    reject(schemaRejection(e.message, property))
                                    break;
                                }
                            } else {
                                reject(schemaRejection("Data object is missing key (" + property + ").", undefined))
                                break;
                            }
                        } else {
                            if(schemaFunction !== null){
                            reject(schemaRejection("Schema object must be in the form {key: (data) => {}}. Check property (" + property + ")", undefined))
                            break;
                            }
                        }
                    }
                    resolve(data)
                } else {
                    reject(schemaRejection("Data object and schema object are different sizes.", undefined))
                }
            } else {
                reject(schemaRejection("Schema is not a json object.", undefined))
            }
        } else {
            reject(schemaRejection("Data is not a json object.", undefined))
        }
    });
};
const schemaRejection = (message, key) => {
    return { message: message, key: key }
}
exports.validateSchema = validateSchema;
exports.schemaRejection = schemaRejection;